==> james-project-3.4.0-source-release.zip: james-project-3.4.0/server/container/guice/cassandra-rabbitmq-guice/src/test/java/org/apache/james/CassandraRabbitMQJamesServerFixture.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.james;

import org.apache.james.modules.RabbitMQExtension;
import org.apache.james.modules.TestJMAPServerModule;

public class CassandraRabbitMQJamesServerFixture {

    private static final int LIMIT_TO_10_MESSAGES = 10;

    private static final JamesServerBuilder.ServerProvider CONFIGURATION_BUILDER =
        configuration -> GuiceJamesServer
            .forConfiguration(configuration)
            .combineWith(CassandraRabbitMQJamesServerMain.MODULES)
            .overrideWith(new TestJMAPServerModule(LIMIT_TO_10_MESSAGES))
            .overrideWith(JmapJamesServerContract.DOMAIN_LIST_CONFIGURATION_MODULE);

    public static JamesServerBuilder baseExtensionBuilder() {
        return baseExtensionBuilder(new RabbitMQExtension());
    }

    public static JamesServerBuilder baseExtensionBuilder(RabbitMQExtension rabbitMQExtension) {
        return new JamesServerBuilder()
            .extension(new DockerElasticSearchExtension())
            .extension(new CassandraExtension())
            .extension(rabbitMQExtension)
            .server(CONFIGURATION_BUILDER);
    }
}

==> james-project-3.5.0-source-release.zip: james-project-3.5.0/server/container/guice/cassandra-rabbitmq-guice/src/test/java/org/apache/james/CassandraRabbitMQJamesServerFixture.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.james;

import org.apache.james.jmap.draft.JmapJamesServerContract;
import org.apache.james.modules.RabbitMQExtension;
import org.apache.james.modules.TestJMAPServerModule;

public class CassandraRabbitMQJamesServerFixture {

    private static final JamesServerBuilder.ServerProvider CONFIGURATION_BUILDER =
        configuration -> GuiceJamesServer
            .forConfiguration(configuration)
            .combineWith(CassandraRabbitMQJamesServerMain.MODULES)
            .overrideWith(TestJMAPServerModule.limitToTenMessages())
            .overrideWith(JmapJamesServerContract.DOMAIN_LIST_CONFIGURATION_MODULE);

    public static JamesServerBuilder baseExtensionBuilder() {
        return baseExtensionBuilder(new RabbitMQExtension());
    }

    public static JamesServerBuilder baseExtensionBuilder(RabbitMQExtension rabbitMQExtension) {
        return new JamesServerBuilder()
            .extension(new DockerElasticSearchExtension())
            .extension(new CassandraExtension())
            .extension(rabbitMQExtension)
            .server(CONFIGURATION_BUILDER);
    }
}
